==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebCore/layout/formattingContexts/grid/GridTypeAliases.h <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

namespace WebCore {

class LayoutUnit;

namespace Layout {

class PlacedGridItem;
class UnplacedGridItem;

struct GridAreaLines;
struct GridItemRect;
struct TrackSizingFunctions;
struct UnsizedTrack;

using GridAreas = HashMap<UnplacedGridItem, GridAreaLines>;
using GridCell = Vector<UnplacedGridItem, 1>;
using GridItemRects = Vector<GridItemRect>;
using GridMatrix = Vector<Vector<GridCell>>;
using PlacedGridItems = Vector<PlacedGridItem>;
using TrackSizes = Vector<LayoutUnit>;
using TrackSizingFunctionsList = Vector<TrackSizingFunctions>;
using UnsizedTracks = Vector<UnsizedTrack>;
} // namespace Layout
} // namespace WebCore

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/layout/formattingContexts/grid/GridTypeAliases.h <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

namespace WebCore {

class LayoutUnit;

namespace Layout {

class PlacedGridItem;
class UnplacedGridItem;

struct GridAreaLines;
struct GridItemRect;
struct TrackSizingFunctions;
struct UnsizedTrack;

using BorderBoxPositions = Vector<LayoutUnit>;
using GridAreas = HashMap<UnplacedGridItem, GridAreaLines>;
using GridCell = Vector<UnplacedGridItem, 1>;
using GridItemRects = Vector<GridItemRect>;
using GridMatrix = Vector<Vector<GridCell>>;
using PlacedGridItems = Vector<PlacedGridItem>;
using TrackSizes = Vector<LayoutUnit>;
using TrackSizingFunctionsList = Vector<TrackSizingFunctions>;
using UnsizedTracks = Vector<UnsizedTrack>;
using UsedBlockSizes = Vector<LayoutUnit>;
using UsedInlineSizes = Vector<LayoutUnit>;
} // namespace Layout
} // namespace WebCore
